@@ -23,4 +23,4 @@
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   437.
 #' @export
-roxygen()
+NULL
