@@ -14,4 +14,5 @@
 #' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
 #'   438.
 #' @export
-roxygen()
+NULL
+
